@@ -73,8 +73,8 @@ sub paper {
 sub paper_size {
   my ($paper_name) = @_;
   chomp($paper_name = paper([])) unless defined($paper_name);
-  my $dimensions = paper(["--unit=pt", "--size", "$paper_name"], 1) or return;
-  $dimensions =~ /^(\S+) (\S+)/;
+  my $dimensions = paper(["--unit=pt", "$paper_name"], 1) or return;
+  $dimensions =~ / ([.0-9]+)x([.0-9]+) pt$/;
   my $old_locale = setlocale(LC_ALL);
   setlocale(LC_ALL, "");
   my ($w, $w_unparsed) = strtod($1);
@@ -87,8 +87,10 @@ sub parsepaper {
   my ($width, $height) = paper_size($_[0]);
   if (!defined($width)) {
     my ($w, $h) = split /x/, $_[0];
-    eval { ($width, $height) = (singledimen($w), singledimen($h)); }
-      or Die("paper size '$_[0]' unknown");
+    if (defined($w) && defined($h)) {
+      eval { ($width, $height) = (singledimen($w), singledimen($h)); }
+        or Die("paper size '$_[0]' unknown");
+    }
   }
   return $width, $height;
 }
@@ -128,9 +130,9 @@ sub parse_file {
           $psinfo->{pagescmt} = $record;
         } elsif ($psinfo->{headerpos} == 0 && $keyword eq "EndComments") {
           $psinfo->{headerpos} = $next_record;
-        } elsif ($keyword eq "BeginDocument" ||
-                   $keyword eq "BeginBinary" ||
-                   $keyword eq "BeginFile") {
+        } elsif ($keyword eq "BeginDocument:" ||
+                   $keyword eq "BeginBinary:" ||
+                   $keyword eq "BeginFile:") {
           $nesting++;
         } elsif ($keyword eq "EndDocument" ||
                    $keyword eq "EndBinary" ||
